@@ -45,7 +45,7 @@ import utils.exiftool as exiftool
 logger = logging.getLogger(__name__)
 
 PILLOW_SUPPORTED_IMAGE_EXTENSIONS = ["bmp","dds","dib","eps","gif","icns","ico","im","jpg","jpeg","jpeg 2000","msp","pcx","png","ppm","sgi","spider","tga","tiff","webp","xbm"]
-
+GET_DATA_INCLUDE_DEFAULT_VALUE = ['file_name', 'extension', 'name_no_ext', 'dir_path', 'access_time', 'modified_time', 'created_time', 'size']
 
 def decompress(file_obj, compression="gzip"):
     '''
@@ -694,7 +694,7 @@ def get_data(file_path, **kwargs):
     if isinstance(data_include, (str)):
         data_include = [data_include]
     if len(data_include) == 0:
-        data_include = ['file_name', 'extension', 'name_no_ext', 'dir_path', 'access_time', 'modified_time', 'created_time', 'size']
+        data_include = GET_DATA_INCLUDE_DEFAULT_VALUE
     file_path = strUtils.format.file_path(file_path)
     if exists(file_path):
         # print(f"file exists: {file_path}")
@@ -1113,18 +1113,20 @@ def get_files(search_path=False, **kwargs):
 
     threaded = obj.get_kwarg(['threaded', 'thread'], True, bool, **kwargs)
     recursive = obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
-    include_meta_data = obj.get_kwarg(['image meta data', 'meta data','include meta data'], False, bool, **kwargs)
 
     data_include = obj.get_kwarg(['data include'], [], (list, str), **kwargs)
     if isinstance(data_include, (str)):
         data_include = [data_include]
-        # if data_include is provided and include_meta_data is True
-        if include_meta_data is True and len(data_include) > 0:
-            # Confirm that extension is in data_include, if not, add it.
-            # The extension is required to gather the data.
-            if "extension" not in data_include:
-                data_include.append("extension")
     
+    if len(data_include) == 0:
+        data_include = GET_DATA_INCLUDE_DEFAULT_VALUE
+        
+    include_meta_data = obj.get_kwarg(['image meta data', 'meta data','include meta data'], False, bool, **kwargs)
+    if include_meta_data is True:
+        if "extension" not in data_include:
+            data_include.append("extension")
+        
+
 
     # ignore_array = obj.get_kwarg(['ignore', 'ignore_array', 'exclude'], [], (str, list), **kwargs)
     exclude = obj.get_kwarg(['exclude', 'ignore', 'ignore array'], [], (list, str), **kwargs)
